var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __name = (target, value) => __defProp(target, "name", { value, configurable: true });
var __export = (target, all) => {
  for (var name2 in all)
    __defProp(target, name2, { get: all[name2], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/index.ts
var index_exports = {};
__export(index_exports, {
  Config: () => Config,
  apply: () => apply,
  inject: () => inject,
  name: () => name,
  usage: () => usage
});
module.exports = __toCommonJS(index_exports);
var import_koishi = require("koishi");
var name = "teleguild";
var usage = "使用文档/更新日志：https://forum.koishi.xyz/t/topic/10178";
var Config = import_koishi.Schema.intersect([
  import_koishi.Schema.object({
    showGuildId: import_koishi.Schema.boolean().default(false).description("是否在通讯录和来电提示中显示群号"),
    badWords: import_koishi.Schema.array(import_koishi.Schema.string()).description("消息中的这些词语转发时会被替换为*"),
    allowPicture: import_koishi.Schema.boolean().default(true).description("消息是否允许包含图片/语音/视频")
  }),
  import_koishi.Schema.intersect([
    import_koishi.Schema.object({
      limit: import_koishi.Schema.union(["不限制", "限制时间", "限制消息量", "限制时间或消息量（其中之一达到就结束）"]).default("不限制").description("限制通话的时间或消息量")
    }),
    import_koishi.Schema.union([
      import_koishi.Schema.object({
        limit: import_koishi.Schema.const("限制时间").required(),
        timeLimit: import_koishi.Schema.number().description("通话时间上限(s)").required()
      }),
      import_koishi.Schema.object({
        limit: import_koishi.Schema.const("限制消息量").required(),
        countLimit: import_koishi.Schema.number().description("通话消息量上限").required()
      }),
      import_koishi.Schema.object({
        limit: import_koishi.Schema.const("限制时间或消息量（其中之一达到就结束）").required(),
        timeLimit: import_koishi.Schema.number().description("通话时间上限(s)").required(),
        countLimit: import_koishi.Schema.number().description("通话消息量上限").required()
      }),
      import_koishi.Schema.object({
        limit: import_koishi.Schema.const("不限制")
      })
    ])
  ]),
  import_koishi.Schema.intersect([
    import_koishi.Schema.object({
      autoGuilds: import_koishi.Schema.boolean().default(true).description("自动获取bot所在的所有群列表添入通讯录")
    }),
    import_koishi.Schema.union([
      import_koishi.Schema.object({
        autoGuilds: import_koishi.Schema.const(false).required(),
        activeGuilds: import_koishi.Schema.array(import_koishi.Schema.object({
          id: import_koishi.Schema.string().description("群号").required(),
          name: import_koishi.Schema.string().description("群名").required()
        })).description("显示在通讯录的群列表").role("table")
      }),
      import_koishi.Schema.object({
        autoGuilds: import_koishi.Schema.const(true)
      })
    ])
  ])
]);
var inject = ["puppeteer", "database"];
function apply(ctx, config) {
  ctx.model.extend("teleguild_protals_auto", {
    callId: "unsigned",
    id: "string",
    name: "string"
  }, { primary: "callId", autoInc: true });
  ctx.model.extend("teleguild_protals_manual", {
    callId: "unsigned",
    id: "string",
    name: "string"
  }, { primary: "callId" });
  let guilds = {};
  ctx.command("群互通", "群消息互通");
  ctx.command("群互通.发起 <guildId:posint>", "向指定群发起群消息互通，ID可在“群互通.通讯录”中查看").example("群互通.发起 114").action(async ({ session }, guildId) => {
    if (guildId == void 0) {
      await session.send("未输入群号");
      await session.execute("群互通.通讯录");
      return;
    }
    let initiatorGuildId = session.guildId;
    let gd = session.bot.getGuild(initiatorGuildId);
    let dbName = config.autoGuilds ? "teleguild_protals_auto" : "teleguild_protals_manual";
    let guild = (await ctx.database.get(dbName, { callId: guildId }))[0];
    if (guild === void 0) {
      guild = (await ctx.database.get(dbName, { id: guildId }))[0];
      if (guild === void 0) {
        try {
          guild = await session.bot.getGuild(String(guildId));
        } catch {
          return "群ID不存在或缓存未刷新，请尝试使用“群互通.通讯录”后重试";
        }
      }
    }
    let targetGuildId = guild.id;
    if (guilds[initiatorGuildId]) return "你所在的群正在通话中";
    if (guild.id === initiatorGuildId) return "不能给自己打电话";
    if (guilds[targetGuildId]) return "对方群正在通话中，请稍后再试";
    guilds[targetGuildId] = initiatorGuildId;
    guilds[initiatorGuildId] = targetGuildId;
    try {
      await session.bot.sendMessage(targetGuildId, `群聊“${(await gd).name}”${config.showGuildId ? `(${initiatorGuildId})` : ""}向本群发起了消息互通请求，请在30秒内发送“接通”或“挂断”`);
      session.bot.sendMessage(initiatorGuildId, `${import_koishi.h.quote(session.messageId)}已向群聊“${guild.name}”发起群消息互通请求`);
    } catch (e) {
      delete guilds[targetGuildId];
      delete guilds[initiatorGuildId];
      ctx.logger("teleguild").warn(e);
      return "发起请求时遇到错误，请查看日志";
    }
    let disposeYesOrNo = ctx.guild(targetGuildId).on("message", async (session2) => {
      if (session2.content === "挂断") {
        disposeTimeout();
        hangUp();
        await session2.bot.sendMessage(targetGuildId, `${import_koishi.h.quote(session2.messageId)}已挂断`);
        await session2.bot.sendMessage(initiatorGuildId, `${import_koishi.h.quote(session2.messageId)}已被对方挂断`);
      } else if (session2.content === "接通") {
        disposeTimeout();
        answer();
      }
    });
    let disposeTimeout = ctx.setTimeout(async () => {
      hangUp();
      await session.bot.sendMessage(targetGuildId, `通话请求回应超时，已自动挂断`);
      await session.bot.sendMessage(initiatorGuildId, `${import_koishi.h.quote(session.messageId)}通话请求回应超时，已自动挂断`);
    }, 3e4);
    function answer() {
      let messages = {};
      disposeYesOrNo();
      let msg = `通话已接通，任何群员都可以发送“挂断”结束通话`;
      if (config.limit === "限制时间") {
        msg += `，通话时间上限为${config.timeLimit}秒`;
      } else if (config.limit === "限制消息量") {
        msg += `，通话消息量上限为${config.countLimit}条`;
      } else if (config.limit === "限制时间或消息量（其中之一达到就结束）") {
        msg += `，通话消息量上限为${config.countLimit}条，通话时间上限为${config.timeLimit}秒`;
      }
      session.bot.sendMessage(initiatorGuildId, `${import_koishi.h.quote(session.messageId)}${msg}`);
      session.bot.sendMessage(targetGuildId, msg);
      let disposeGuild1 = ctx.self(session.selfId).guild(targetGuildId).exclude((session2) => session2.userId === session2.selfId).on("message", async (session2) => {
        if (session2.content === "挂断") {
          hangUpWithMessage(targetGuildId);
        } else {
          await relayMessage(session2, initiatorGuildId);
        }
      });
      let disposeGuild2 = ctx.self(session.selfId).guild(initiatorGuildId).exclude((session2) => session2.userId === session2.selfId).on("message", async (session2) => {
        if (session2.content === "挂断") {
          hangUpWithMessage(initiatorGuildId);
        } else {
          await relayMessage(session2, targetGuildId);
        }
      });
      let disposeMaxTime;
      let relayMessage;
      if (config.limit === "限制消息量") {
        messageLimit();
      } else if (config.limit === "限制时间或消息量（其中之一达到就结束）") {
        timeLimit();
        messageLimit();
      } else {
        if (config.limit === "限制时间") {
          timeLimit();
        }
        relayMessage = /* @__PURE__ */ __name(async (session2, guildId2) => {
          if (!config.allowPicture && (session2.content.includes("<audio") || session2.content.includes("<video") || session2.content.includes("<img"))) {
            session2.send(import_koishi.h.quote(session2.messageId) + "消息中不可包含图片/语音/视频");
            return;
          }
          let content = "";
          let date = /* @__PURE__ */ new Date();
          if (messages[session2?.quote?.id] !== void 0) {
            content += import_koishi.h.quote(messages[session2.quote.id]);
          }
          content += `[${session2.username} ${("00" + date.getHours()).slice(-2)}:${("00" + date.getMinutes()).slice(-2)}:${("00" + date.getSeconds()).slice(-2)}]<br/>`;
          content += session2.content;
          config.badWords.forEach((badWord) => {
            content = content.replaceAll(badWord, "*".repeat(badWord.length));
          });
          messages[(await session2.bot.sendMessage(guildId2, content))[0]] = session2.messageId;
        }, "relayMessage");
      }
      let disposeTip = ctx.setInterval(() => {
        session.bot.sendMessage(initiatorGuildId, `任何群友都可以发送“挂断”结束当前通话哦`);
        session.bot.sendMessage(targetGuildId, `任何群友都可以发送“挂断”结束当前通话哦`);
      }, 12e4);
      function timeLimit() {
        disposeMaxTime = ctx.setTimeout(() => {
          disposeGuild1();
          disposeGuild2();
          disposeTip();
          delete guilds[targetGuildId];
          delete guilds[initiatorGuildId];
          session.bot.sendMessage(initiatorGuildId, `时间到达上限，已挂断通话`);
          session.bot.sendMessage(targetGuildId, `时间到达上限，已挂断通话`);
        }, config.timeLimit * 1e3);
      }
      __name(timeLimit, "timeLimit");
      function messageLimit() {
        let messageCount = 0;
        relayMessage = /* @__PURE__ */ __name(async (session2, guildId2) => {
          if (!config.allowPicture && (session2.content.includes("<audio") || session2.content.includes("<video") || session2.content.includes("<img"))) {
            session2.send(import_koishi.h.quote(session2.messageId) + "消息中不可包含图片/语音/视频");
            return;
          }
          let content = "";
          let date = /* @__PURE__ */ new Date();
          if (messages[session2?.quote?.id] !== void 0) {
            content += import_koishi.h.quote(messages[session2.quote.id]);
          }
          content += `[${session2.username} ${("00" + date.getHours()).slice(-2)}:${("00" + date.getMinutes()).slice(-2)}:${("00" + date.getSeconds()).slice(-2)}]<br/>`;
          content += session2.content;
          config.badWords.forEach((badWord) => {
            content = content.replaceAll(badWord, "*".repeat(badWord.length));
          });
          messageCount++;
          if (messageCount >= config.countLimit) {
            disposeGuild1();
            disposeGuild2();
            disposeTip();
            if (disposeMaxTime !== void 0) disposeMaxTime();
            delete guilds[targetGuildId];
            delete guilds[initiatorGuildId];
            await session2.bot.sendMessage(guildId2, content);
            session2.bot.sendMessage(initiatorGuildId, `消息量到达上限，已挂断通话`);
            session2.bot.sendMessage(targetGuildId, `消息量到达上限，已挂断通话`);
          } else {
            messages[(await session2.bot.sendMessage(guildId2, content))[0]] = session2.messageId;
          }
        }, "relayMessage");
      }
      __name(messageLimit, "messageLimit");
      async function hangUpWithMessage(id) {
        disposeGuild1();
        disposeGuild2();
        disposeTip();
        if (disposeMaxTime !== void 0) disposeMaxTime();
        session.bot.sendMessage(id, `通话已挂断`);
        session.bot.sendMessage(guilds[id], `对方已挂断`);
        delete guilds[targetGuildId];
        delete guilds[initiatorGuildId];
      }
      __name(hangUpWithMessage, "hangUpWithMessage");
    }
    __name(answer, "answer");
    function hangUp() {
      disposeYesOrNo();
      delete guilds[targetGuildId];
      delete guilds[initiatorGuildId];
    }
    __name(hangUp, "hangUp");
  });
  ctx.command("群互通.通讯录", "查看群通讯录").action(async ({ session }) => {
    let dbName;
    if (config.autoGuilds) {
      dbName = "teleguild_protals_auto";
      let guilds2 = [];
      for await (let guild of session.bot.getGuildIter()) {
        guilds2.push(guild);
      }
      await ctx.database.upsert("teleguild_protals_auto", guilds2, ["id", "name"]);
    } else {
      dbName = "teleguild_protals_manual";
      await ctx.database.remove("teleguild_protals_manual", {});
      let activeGuilds = [];
      for (let index = 1; index <= config.activeGuilds.length; index++) {
        activeGuilds.push({
          callId: index,
          id: config.activeGuilds[index - 1].id,
          name: config.activeGuilds[index - 1].name
        });
      }
      await ctx.database.upsert("teleguild_protals_manual", activeGuilds, ["id", "name"]);
    }
    let rows = [];
    if (config.showGuildId) {
      for (let guild of await ctx.database.get(dbName, {})) {
        rows.push("<tr>");
        rows.push(`<td>${guild.callId}</td>`);
        rows.push(`<td>${guild.name}</td>`);
        rows.push(`<td>${guild.id}</td>`);
        rows.push("</tr>");
      }
    } else {
      for (let guild of await ctx.database.get(dbName, {})) {
        rows.push("<tr>");
        rows.push(`<td>${guild.callId}</td>`);
        rows.push(`<td>${guild.name}</td>`);
        rows.push("</tr>");
      }
    }
    return await ctx.puppeteer.render(
      `<html style="width: fit-content">
          <head>
            <style>
              th {
                background:#f3f3f3 !important;
              }
            </style>
          </head>
        
          <body style="height: fit-content; min-height: 50%">
            <table border="1" cellpadding="5" style="margin: 10px; border-collapse: collapse">
              <tbody align="center" valign="center">
                <tr>
                  <th>ID</th>
                  <th>群名</th>
                  ${config.showGuildId ? "<th>群号</th>" : ""}
                </tr>
                ${rows.join("\n")}
              </tbody>
            </table>
          </body>
        </html>`
    );
  });
  ctx.command("测试测试").action(({ session }) => {
    console.log(session.content);
  });
}
__name(apply, "apply");
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  Config,
  apply,
  inject,
  name,
  usage
});
